%bcond_with     jp_minimal

Name:          rome
Version:       1.7.0
Release:       6%{?dist}
Summary:       RSS and Atom Utilities
License:       ASL 2.0
URL:           http://rometools.github.io/rome/
# Original source archive 73,8 MB
# sh rome-create-tarball.sh < VERSION >
# Repackaged source archive 575 KB
Source0:       %{name}-%{version}.tar.xz
Source1:       %{name}-create-tarball.sh

BuildRequires: maven-local
BuildRequires: mvn(commons-beanutils:commons-beanutils)
BuildRequires: mvn(commons-httpclient:commons-httpclient)
BuildRequires: mvn(javax.persistence:persistence-api)
BuildRequires: mvn(javax.servlet:javax.servlet-api)
BuildRequires: mvn(junit:junit)
%if %{without jp_minimal}
BuildRequires: mvn(net.oauth.core:oauth)
%endif
BuildRequires: mvn(org.apache.commons:commons-lang3)
BuildRequires: mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires: mvn(org.apache.xmlrpc:xmlrpc-client)
BuildRequires: mvn(org.hamcrest:hamcrest-library)
BuildRequires: mvn(org.jdom:jdom2)
BuildRequires: mvn(org.slf4j:slf4j-api)
BuildRequires: mvn(org.sonatype.oss:oss-parent:pom:)
BuildRequires: mvn(xmlunit:xmlunit)

BuildArch:     noarch

%description
ROME is an set of open source Java tools for parsing, generating and
publishing RSS and Atom feeds.

%package certiorem
Summary:       A PubSubHubub implementation for Java based on ROME

%description certiorem
PubSubHubub protocol implementation based on ROME.

%package fetcher
Summary:       Retrieves RSS feeds via HTTP conditional gets using ROME

%description fetcher
ROME Fetcher is a caching feed fetcher that supports retrieval of
feeds via HTTP conditional GET. Supports ETags, GZip compression,
and RFC3229 Delta encoding.

%package modules
Summary:       Plugin collection for the ROME RSS and Atom Utilities
# LGPL:
# rome-modules/src/main/java/com/rometools/modules/base/Course.java
# rome-modules/src/main/java/com/rometools/modules/base/CustomTagImpl.java
# rome-modules/src/main/java/com/rometools/modules/content/ContentItem.java
# rome-modules/src/main/java/com/rometools/modules/itunes/types/Duration.java
# rome-modules/src/main/java/com/rometools/modules/photocast/PhotocastModule.java
# rome-modules/src/main/java/com/rometools/modules/slash/Slash.java
# rome-modules/src/main/java/com/rometools/modules/yahooweather/YWeatherEntryModule.java
License:       ASL 2.0 and LGPLv2

%description modules
This module contains extensions that enable ROME to
handle several feed extensions like MediaRSS,
GeoRSS and others.

%package opml
Summary:       Support for OPML 1 and OPML 2 in ROME

%description opml
This module contains Outline Processor Markup Language parser and tools.

%package propono
Summary:       ROME Propono

%description propono
The ROME Propono sub-project is a Java class library that
supports publishing protocols, specifically the Atom Publishing Protocol
and the legacy MetaWeblog API. Propono includes an Atom client library,
Atom server framework and a Blog client that supports both Atom protocol
and the MetaWeblog API. 

%package utils
Summary:       Utility classes for ROME projects

%description utils
This modules provides utility classes for all ROME projects.

%package javadoc
Summary:       Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q

# Unneeded tasks
%pom_remove_plugin -r :maven-scm-publish-plugin

%pom_xpath_remove -r "pom:Embed-Dependency" %{name} %{name}-modules
%pom_xpath_remove "pom:Embed-Transitive" %{name}-modules

%pom_change_dep -r com.rometools: ::'${project.version}'

# Force servlet 3.1
%pom_change_dep -r :servlet-api javax.servlet:javax.servlet-api:3.1.0
sed -i "s|String, Object|String, String[]|" \
 %{name}-propono/src/main/java/com/rometools/propono/atom/server/AtomRequestImpl.java \
 %{name}-propono/src/main/java/com/rometools/propono/atom/server/AtomRequest.java

# com.google.inject.extensions:guice-servlet
%pom_disable_module rome-certiorem-webapp
# No test deps (contains only tests)
# org.ops4j.pax.exam:pax-exam-container-native:4.8.0
# org.ops4j.pax.exam:pax-exam-junit4:4.8.0
# org.ops4j.pax.exam:pax-exam-link-mvn:4.8.0
# org.ops4j.pax.url:pax-url-wrap:2.4.5
%pom_disable_module rome-osgi-test

# Unecessary test dep
# ch.qos.logback:logback-classic
%pom_remove_dep -r ch.qos.logback:

# Unavailable test dep
# jetty:jetty:4.2.12
%pom_remove_dep -r jetty:jetty
rm %{name}-fetcher/src/test/java/com/rometools/fetcher/AbstractJettyTest.java \
 %{name}-fetcher/src/test/java/com/rometools/fetcher/impl/HttpClientFeedFetcherTest.java \
 %{name}-fetcher/src/test/java/com/rometools/fetcher/impl/HttpURLFeedFetcherTest.java \
 %{name}-propono/src/test/java/com/rometools/propono/atom/server/AtomClientServerTest.java \
 %{name}-propono/src/test/java/com/rometools/propono/atom/server/TestAtomHandlerImpl.java \
 %{name}-propono/src/test/java/com/rometools/propono/atom/server/TestAtomHandlerFactory.java

# Conditionally build oauth support
%if %{with jp_minimal}
%pom_remove_dep net.oauth.core: rome-propono
rm rome-propono/src/main/java/com/rometools/propono/atom/client/OAuthStrategy.java
%endif

# Convert from dos to unix line ending
sed -i.orig 's|\r||g' README.md
touch -r README.md.orig README.md
rm README.md.orig

# @ random fails: AssertionError
rm %{name}-modules/src/test/java/com/rometools/modules/cc/types/LicenseTest.java

%mvn_alias com.rometools:%{name} %{name}:%{name} net.java.dev.%{name}:%{name}
# Avoid problems with old rome-parent-1.5.0 package
%mvn_package :%{name}-parent %{name}

%build

%mvn_build -s 

%install
%mvn_install

%files -f .mfiles-%{name}
%files certiorem -f .mfiles-%{name}-certiorem
%files fetcher -f .mfiles-%{name}-fetcher
%files modules -f .mfiles-%{name}-modules
%files opml -f .mfiles-%{name}-opml

%files propono -f .mfiles-%{name}-propono
%license %{name}-propono/NOTICE

%files utils -f .mfiles-%{name}-utils
%doc README.md
%license LICENSE

%files javadoc -f .mfiles-javadoc
%license LICENSE

%changelog
* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.7.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Mon Jun 11 2018 Mat Booth <mat.booth@redhat.com> - 1.7.0-5
- Drop unnecessary test dep on logback
- Conditionally build support for additional auth strategies

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.7.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.7.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.7.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Sat Oct 15 2016 gil cattaneo <puntogil@libero.it> 1.7.0-1
- update to 1.7.0

* Thu Sep 15 2016 gil cattaneo <puntogil@libero.it> 1.6.0-3
- remove test failure

* Tue Apr 12 2016 gil cattaneo <puntogil@libero.it> 1.6.0-2
- rebuilt

* Mon Apr 11 2016 gil cattaneo <puntogil@libero.it> 1.6.0-1
- update to 1.6.0

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.9-20
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Jun 23 2015 Mat Booth <mat.booth@redhat.com> - 0.9-19
- Adopt xmvn

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9-18
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon Jun 9 2014 Alexander Kurtakov <akurtako@redhat.com> 0.9-17
- Fix FTBFS.

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9-16
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri Feb 21 2014 Alexander Kurtakov <akurtako@redhat.com> 0.9-15
- Require java-headless.

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri May 25 2012 gil cattaneo <puntogil@libero.it> 0.9-11
- Added maven POM

* Tue Apr 17 2012 Alexander Kurtakov <akurtako@redhat.com> 0.9-10
- Adapt to current guidelines.

* Fri Apr 13 2012 Krzysztof Daniel <kdaniel@redhat.com> 0.9-9
- Use Java 7
- Use latest jdom

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Feb 15 2010 Alexander Kurtakov <akurtako@redhat.com> 0.9-6
- Fix build with latest jdom. (rhbz#565057)

* Mon Jan 11 2010 Andrew Overholt <overholt@redhat.com> 0.9-5
- Update URL in instructions for getting MANIFEST.

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Mon Mar 30 2009 Andrew Overholt <overholt@redhat.com> 0.9-3
- Fix javadoc Group (rhbz#492761).

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Fri Jul 25 2008 Andrew Overholt <overholt@redhat.com> 0.9-1
- Initial Fedora version
